using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using DVM_Management_Center.FileIO;
using DVM_Management_Center.Mail;

namespace DVM_Management_Center.GUI
{
    public partial class MailAlert : Form
    {
        const String MAIL_CONFIG_FILE = "mailsettings.xml";
        public MailAlert()
        {
            InitializeComponent();
        }

        private void btClose_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void MailAlert_Load(object sender, EventArgs e)
        {
            Xml_Serializer xmlS = new Xml_Serializer(Application.StartupPath + "/" + MAIL_CONFIG_FILE);
            try
            {
                AlertSettings alertSettings = (AlertSettings)xmlS.DeserializeObject(typeof(AlertSettings));

                tbRecipient.Text = alertSettings.Receiver;
                tbSender.Text = alertSettings.Sender;

                tbHost.Text = alertSettings.Host;
                tbPassword.Text = alertSettings.Password;
                tbPort.Text = alertSettings.Port;
                tbUser.Text = alertSettings.Username;

                cbConnectivity.Checked = alertSettings.BlConnectivity;
                numConnectivity.Enabled = alertSettings.BlConnectivity;
                numConnectivity.Text = alertSettings.TbConnectivity.ToString();

                cbSyncLoss.Checked = alertSettings.BlSyncLoss;
                numSyncLoss.Enabled = alertSettings.BlSyncLoss;
                numSyncLoss.Text = alertSettings.TbSyncLoss.ToString();

                cbAlarm.Checked = alertSettings.BlAlarm;
                numAlarm.Enabled = alertSettings.BlAlarm;
                numAlarm.Text = alertSettings.TbAlarm.ToString();

                cbEntry.Checked = alertSettings.BlEntry;

                numericUpDown.Value = alertSettings.HoursDelay;
            }
            catch
            {
                MessageBox.Show("The mail settings could not be loaded!");
            }
        }

        private void tbInt_Leave(object sender, EventArgs e)
        {
            int var;
            int.TryParse(((TextBox)sender).Text, out var);
                ((TextBox)sender).Text = var.ToString();
        }

        private void cbConnectivity_CheckedChanged(object sender, EventArgs e)
        {
            if (cbConnectivity.Checked == false)
                numConnectivity.Enabled = false;
            else
                numConnectivity.Enabled = true;
        }

        private void cbSyncLoss_CheckedChanged(object sender, EventArgs e)
        {
            if (cbSyncLoss.Checked == false)
                numSyncLoss.Enabled = false;
            else
                numSyncLoss.Enabled = true;
        }

        private void cbAlarm_CheckedChanged(object sender, EventArgs e)
        {
            if (cbAlarm.Checked == false)
                numAlarm.Enabled = false;
            else
                numAlarm.Enabled = true;
        }

        private void MailAlert_FormClosing(object sender, FormClosingEventArgs e)
        {
            Xml_Serializer xmlS = new Xml_Serializer(Application.StartupPath + "/" + MAIL_CONFIG_FILE);
            AlertSettings alertSettings = new AlertSettings();

            alertSettings.Receiver = tbRecipient.Text;
            alertSettings.Sender = tbSender.Text;
            alertSettings.Host = tbHost.Text;
            alertSettings.Password = tbPassword.Text;
            alertSettings.Port = tbPort.Text;
            alertSettings.Username = tbUser.Text;
            alertSettings.BlConnectivity = cbConnectivity.Checked;
            alertSettings.TbConnectivity = Int32.Parse(numConnectivity.Text);
            alertSettings.BlSyncLoss = cbSyncLoss.Checked;
            alertSettings.TbSyncLoss = Int32.Parse(numSyncLoss.Text);
            alertSettings.BlAlarm = cbAlarm.Checked;
            alertSettings.TbAlarm = Int32.Parse(numAlarm.Text);
            alertSettings.BlEntry = cbEntry.Checked;
            alertSettings.HoursDelay = Int32.Parse(numericUpDown.Value.ToString());
            xmlS.SerializeObject((object)alertSettings);
        }
    }
}