/*Class name: DVMBasics
 *Namespace: DVM_Management_Center.SNMP
 *Author: Harald Gsoedl
 *Last Change: Benno Rott
 *Changed: 21/02/2007
 *Use: Provides basic routines to read infos from the DVM. Including all necessary OIDs.
 */

using System;
using System.Collections;
using System.Collections.Generic;
using System.Text;

namespace DVM_Management_Center.SNMP
{
    class DVMBasics:SNMPBasics
    {
        Hashtable DVMOIDS = new Hashtable();

        /// <summary>
        /// Constructor with a Hashtable of OIDs
        /// </summary>
        /// <param name="ip">IP from the DVM</param>
        /// <param name="readCommunity">The DVM Read-Community-String</param>
        /// <param name="writeCommunity">The DVM Write-Community-String</param>
        /// <param name="mibPath"></param>
        public DVMBasics(string ip, string readCommunity, string writeCommunity, string mibPath):base(ip,readCommunity,writeCommunity,mibPath)
        {
            DVMOIDS.Add("AnalyzerCount", ".1.3.6.1.4.1.2566.127.1.1.157.3.1.2.1.0");
            DVMOIDS.Add("AnalyzerMACs", "1.3.6.1.4.1.2566.127.1.1.157.3.1.2.2.1.2.");
            DVMOIDS.Add("SiteName", ".1.3.6.1.4.1.2566.127.1.1.157.3.1.1.1.0");
            DVMOIDS.Add("PortInputName", ".1.3.6.1.4.1.2566.127.1.1.157.3.1.2.5.1.5.");
            DVMOIDS.Add("PortType", ".1.3.6.1.4.1.2566.127.1.1.157.3.1.2.5.1.3.");
            DVMOIDS.Add("PortConfig", ".1.3.6.1.4.1.2566.127.1.1.157.3.1.2.5.1.4.");
            DVMOIDS.Add("PortLED", ".1.3.6.1.4.1.2566.127.1.1.157.3.1.2.5.1.20.");
            DVMOIDS.Add("AnalyzerPortFolderName", ".1.3.6.1.4.1.2566.127.1.1.157.3.1.2.5.1.6.");
            DVMOIDS.Add("ClearLogs", ".1.3.6.1.4.1.2566.127.1.1.157.3.1.3.9.1.2.");
            DVMOIDS.Add("AnalyzerPortBitfield", ".1.3.6.1.4.1.2566.127.1.1.157.3.1.2.5.1.21.");
        }

        public string GetAnalyzerCount()
        {
            return this.GetSimpleSNMPValue(DVMOIDS["AnalyzerCount"].ToString());
        }

        public string GetAnalyzerMACs(int analNo)
        {
            return this.GetSimpleSNMPValue(DVMOIDS["AnalyzerMACs"].ToString() + analNo.ToString());
        }

        public string GetSiteName()
        {
            return this.GetSimpleSNMPValue(DVMOIDS["SiteName"].ToString());
        }

        public string GetAnalyzerMACAddress(int macNo)
        {
            return this.GetSimpleSNMPValue(DVMOIDS["AnalyzerMACs"].ToString() + macNo.ToString());
        }

        public Hashtable GetAllInformation(string mac, int portNo)
        {
            String[] infoOIDs = new String[6];
            
            infoOIDs[0] = DVMOIDS["PortInputName"].ToString() + mac + portNo.ToString();
            infoOIDs[1] = DVMOIDS["PortType"].ToString() + mac + portNo.ToString();
            infoOIDs[2] = DVMOIDS["PortConfig"].ToString() + mac + portNo.ToString();
            infoOIDs[3] = DVMOIDS["PortLED"].ToString() + mac + portNo.ToString(); 
            infoOIDs[4] = DVMOIDS["AnalyzerPortFolderName"].ToString() + mac + portNo.ToString(); // Folder Name
            infoOIDs[5] = DVMOIDS["AnalyzerPortBitfield"].ToString() + mac + portNo.ToString();
            
            return this.GetMultiVals(infoOIDs);
        }

        public void SetClearLogs(string mac, int portNo)
        {
            SetIntValue(DVMOIDS["ClearLogs"].ToString() + mac + portNo.ToString(), 1);
        }
    }
}
